Class: Google::Cloud::VmwareEngine::V1::Cluster
- Inherits:
-
Object
- Object
- Google::Cloud::VmwareEngine::V1::Cluster
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb
Overview
A cluster in a private cloud.
Defined Under Namespace
Modules: State Classes: NodeTypeConfigsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#management ⇒ ::Boolean
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#node_type_configs ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::VmwareEngine::V1::NodeTypeConfig}
Required.
-
#state ⇒ ::Google::Cloud::VmwareEngine::V1::Cluster::State
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Creation time of this resource.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 209 class Cluster include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::VmwareEngine::V1::NodeTypeConfig] class NodeTypeConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enum State defines possible states of private cloud clusters. module State # The default value. This value should never be used. STATE_UNSPECIFIED = 0 # The Cluster is operational and can be used by the user. ACTIVE = 1 # The Cluster is being deployed. CREATING = 2 # Adding or removing of a node to the cluster, any other cluster specific # updates. UPDATING = 3 # The Cluster is being deleted. DELETING = 4 # The Cluster is undergoing maintenance, for example: a failed node is # getting replaced. REPAIRING = 5 end end |
#management ⇒ ::Boolean (readonly)
Returns Output only. True if the cluster is a management cluster; false otherwise. There can only be one management cluster in a private cloud and it has to be the first one.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 209 class Cluster include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::VmwareEngine::V1::NodeTypeConfig] class NodeTypeConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enum State defines possible states of private cloud clusters. module State # The default value. This value should never be used. STATE_UNSPECIFIED = 0 # The Cluster is operational and can be used by the user. ACTIVE = 1 # The Cluster is being deployed. CREATING = 2 # Adding or removing of a node to the cluster, any other cluster specific # updates. UPDATING = 3 # The Cluster is being deleted. DELETING = 4 # The Cluster is undergoing maintenance, for example: a failed node is # getting replaced. REPAIRING = 5 end end |
#name ⇒ ::String (readonly)
Returns Output only. The resource name of this cluster.
Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/us-central1-a/privateClouds/my-cloud/clusters/my-cluster.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 209 class Cluster include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::VmwareEngine::V1::NodeTypeConfig] class NodeTypeConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enum State defines possible states of private cloud clusters. module State # The default value. This value should never be used. STATE_UNSPECIFIED = 0 # The Cluster is operational and can be used by the user. ACTIVE = 1 # The Cluster is being deployed. CREATING = 2 # Adding or removing of a node to the cluster, any other cluster specific # updates. UPDATING = 3 # The Cluster is being deleted. DELETING = 4 # The Cluster is undergoing maintenance, for example: a failed node is # getting replaced. REPAIRING = 5 end end |
#node_type_configs ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::VmwareEngine::V1::NodeTypeConfig}
Returns Required. The map of cluster node types in this cluster, where the key is
canonical identifier of the node type (corresponds to the NodeType).
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 209 class Cluster include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::VmwareEngine::V1::NodeTypeConfig] class NodeTypeConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enum State defines possible states of private cloud clusters. module State # The default value. This value should never be used. STATE_UNSPECIFIED = 0 # The Cluster is operational and can be used by the user. ACTIVE = 1 # The Cluster is being deployed. CREATING = 2 # Adding or removing of a node to the cluster, any other cluster specific # updates. UPDATING = 3 # The Cluster is being deleted. DELETING = 4 # The Cluster is undergoing maintenance, for example: a failed node is # getting replaced. REPAIRING = 5 end end |
#state ⇒ ::Google::Cloud::VmwareEngine::V1::Cluster::State (readonly)
Returns Output only. State of the resource.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 209 class Cluster include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::VmwareEngine::V1::NodeTypeConfig] class NodeTypeConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enum State defines possible states of private cloud clusters. module State # The default value. This value should never be used. STATE_UNSPECIFIED = 0 # The Cluster is operational and can be used by the user. ACTIVE = 1 # The Cluster is being deployed. CREATING = 2 # Adding or removing of a node to the cluster, any other cluster specific # updates. UPDATING = 3 # The Cluster is being deleted. DELETING = 4 # The Cluster is undergoing maintenance, for example: a failed node is # getting replaced. REPAIRING = 5 end end |
#uid ⇒ ::String (readonly)
Returns Output only. System-generated unique identifier for the resource.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 209 class Cluster include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::VmwareEngine::V1::NodeTypeConfig] class NodeTypeConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enum State defines possible states of private cloud clusters. module State # The default value. This value should never be used. STATE_UNSPECIFIED = 0 # The Cluster is operational and can be used by the user. ACTIVE = 1 # The Cluster is being deployed. CREATING = 2 # Adding or removing of a node to the cluster, any other cluster specific # updates. UPDATING = 3 # The Cluster is being deleted. DELETING = 4 # The Cluster is undergoing maintenance, for example: a failed node is # getting replaced. REPAIRING = 5 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last update time of this resource.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 209 class Cluster include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::VmwareEngine::V1::NodeTypeConfig] class NodeTypeConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enum State defines possible states of private cloud clusters. module State # The default value. This value should never be used. STATE_UNSPECIFIED = 0 # The Cluster is operational and can be used by the user. ACTIVE = 1 # The Cluster is being deployed. CREATING = 2 # Adding or removing of a node to the cluster, any other cluster specific # updates. UPDATING = 3 # The Cluster is being deleted. DELETING = 4 # The Cluster is undergoing maintenance, for example: a failed node is # getting replaced. REPAIRING = 5 end end |