Class: Google::Cloud::VmwareEngine::V1::HcxActivationKey

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb

Overview

HCX activation key. A default key is created during private cloud provisioning, but this behavior is subject to change and you should always verify active keys. Use VmwareEngine.ListHcxActivationKeys to retrieve existing keys and VmwareEngine.CreateHcxActivationKey to create new ones.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#activation_key ⇒ ::String (readonly)

Returns Output only. HCX activation key.

Returns:

  • (::String) —

    Output only. HCX activation key.



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 367

class HcxActivationKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of HCX activation key
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # State of a newly generated activation key.
    AVAILABLE = 1

    # State of key when it has been used to activate HCX appliance.
    CONSUMED = 2

    # State of key when it is being created.
    CREATING = 3
  end
end

#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)

Returns Output only. Creation time of HCX activation key.

Returns:



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 367

class HcxActivationKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of HCX activation key
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # State of a newly generated activation key.
    AVAILABLE = 1

    # State of key when it has been used to activate HCX appliance.
    CONSUMED = 2

    # State of key when it is being created.
    CREATING = 3
  end
end

#name ⇒ ::String (readonly)

Returns Output only. The resource name of this HcxActivationKey. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. For example: projects/my-project/locations/us-central1/privateClouds/my-cloud/hcxActivationKeys/my-key.

Returns:

  • (::String) —

    Output only. The resource name of this HcxActivationKey. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. For example: projects/my-project/locations/us-central1/privateClouds/my-cloud/hcxActivationKeys/my-key



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 367

class HcxActivationKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of HCX activation key
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # State of a newly generated activation key.
    AVAILABLE = 1

    # State of key when it has been used to activate HCX appliance.
    CONSUMED = 2

    # State of key when it is being created.
    CREATING = 3
  end
end

#state ⇒ ::Google::Cloud::VmwareEngine::V1::HcxActivationKey::State (readonly)

Returns Output only. State of HCX activation key.

Returns:



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 367

class HcxActivationKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of HCX activation key
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # State of a newly generated activation key.
    AVAILABLE = 1

    # State of key when it has been used to activate HCX appliance.
    CONSUMED = 2

    # State of key when it is being created.
    CREATING = 3
  end
end

#uid ⇒ ::String (readonly)

Returns Output only. System-generated unique identifier for the resource.

Returns:

  • (::String) —

    Output only. System-generated unique identifier for the resource.



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 367

class HcxActivationKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of HCX activation key
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # State of a newly generated activation key.
    AVAILABLE = 1

    # State of key when it has been used to activate HCX appliance.
    CONSUMED = 2

    # State of key when it is being created.
    CREATING = 3
  end
end