Class: Google::Cloud::VmwareEngine::V1::ListHcxActivationKeysResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vmwareengine/v1/vmwareengine.rb

Overview

Response message for VmwareEngine.ListHcxActivationKeys

Instance Attribute Summary collapse

Instance Attribute Details

#hcx_activation_keys ⇒ ::Array<::Google::Cloud::VmwareEngine::V1::HcxActivationKey>

Returns List of HCX activation keys.

Returns:



657
658
659
660
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine.rb', line 657

class ListHcxActivationKeysResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token ⇒ ::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String) —

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



657
658
659
660
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine.rb', line 657

class ListHcxActivationKeysResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable ⇒ ::Array<::String>

Returns Locations that could not be reached when making an aggregated query using wildcards.

Returns:

  • (::Array<::String>) —

    Locations that could not be reached when making an aggregated query using wildcards.



657
658
659
660
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine.rb', line 657

class ListHcxActivationKeysResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end