Class: Google::Cloud::VmwareEngine::V1::ListNetworkPoliciesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vmwareengine/v1/vmwareengine.rb

Overview

Response message for VmwareEngine.ListNetworkPolicies

Instance Attribute Summary collapse

Instance Attribute Details

#network_policies ⇒ ::Array<::Google::Cloud::VmwareEngine::V1::NetworkPolicy>

Returns A list of network policies.

Returns:



825
826
827
828
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine.rb', line 825

class ListNetworkPoliciesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token ⇒ ::String

Returns A token, which can be send as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String) —

    A token, which can be send as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



825
826
827
828
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine.rb', line 825

class ListNetworkPoliciesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable ⇒ ::Array<::String>

Returns Locations that could not be reached when making an aggregated query using wildcards.

Returns:

  • (::Array<::String>) —

    Locations that could not be reached when making an aggregated query using wildcards.



825
826
827
828
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine.rb', line 825

class ListNetworkPoliciesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end