Class: Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService
- Inherits:
-
Object
- Object
- Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb
Overview
Represents a network service that is managed by a NetworkPolicy resource.
A network service provides a way to control an aspect of external access to
VMware workloads. For example, whether the VMware workloads in the
private clouds governed by a network policy can access or be accessed from
the internet.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
True if the service is enabled; false otherwise.
-
#state ⇒ ::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State
readonly
Output only.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns True if the service is enabled; false otherwise.
1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 1284 class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end |
#state ⇒ ::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State (readonly)
Returns Output only. State of the service. New values may be added to this enum when appropriate.
1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 1284 class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end |