Class: Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb

Overview

VMware Engine network resource that provides connectivity for VMware Engine private clouds.

Defined Under Namespace

Modules: State, Type Classes: VpcNetwork

Instance Attribute Summary collapse

Instance Attribute Details

#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)

Returns Output only. Creation time of this resource.

Returns:



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end

#description ⇒ ::String

Returns User-provided description for this VMware Engine network.

Returns:

  • (::String) —

    User-provided description for this VMware Engine network.



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end

#etag ⇒ ::String

Returns Checksum that may be sent on update and delete requests to ensure that the user-provided value is up to date before the server processes a request. The server computes checksums based on the value of other fields in the request.

Returns:

  • (::String) —

    Checksum that may be sent on update and delete requests to ensure that the user-provided value is up to date before the server processes a request. The server computes checksums based on the value of other fields in the request.



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end

#name ⇒ ::String (readonly)

Returns Output only. The resource name of the VMware Engine network. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. For example: projects/my-project/locations/global/vmwareEngineNetworks/my-network.

Returns:

  • (::String) —

    Output only. The resource name of the VMware Engine network. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. For example: projects/my-project/locations/global/vmwareEngineNetworks/my-network



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end

#state ⇒ ::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::State (readonly)

Returns Output only. State of the VMware Engine network.

Returns:



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end

#type ⇒ ::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::Type

Returns Required. VMware Engine network type.

Returns:



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end

#uid ⇒ ::String (readonly)

Returns Output only. System-generated unique identifier for the resource.

Returns:

  • (::String) —

    Output only. System-generated unique identifier for the resource.



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end

#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)

Returns Output only. Last update time of this resource.

Returns:



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end

#vpc_networks ⇒ ::Array<::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork> (readonly)

Returns Output only. VMware Engine service VPC networks that provide connectivity from a private cloud to customer projects, the internet, and other Google Cloud services.

Returns:



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 602

class VmwareEngineNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a VMware Engine VPC network that is managed by a
  # VMware Engine network resource.
  # @!attribute [r] type
  #   @return [::Google::Cloud::VmwareEngine::V1::VmwareEngineNetwork::VpcNetwork::Type]
  #     Output only. Type of VPC network (INTRANET, INTERNET, or
  #     GOOGLE_CLOUD)
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The relative resource name of the service VPC network this
  #     VMware Engine network is attached to. For example:
  #     `projects/123123/global/networks/my-network`
  class VpcNetwork
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum Type defines possible types of a VMware Engine network controlled
    # service.
    module Type
      # The default value. This value should never be used.
      TYPE_UNSPECIFIED = 0

      # VPC network that will be peered with a consumer VPC network or the
      # intranet VPC of another VMware Engine network. Access a private cloud
      # through Compute Engine VMs on a peered VPC network or an on-premises
      # resource connected to a peered consumer VPC network.
      INTRANET = 1

      # VPC network used for internet access to and from a private cloud.
      INTERNET = 2

      # VPC network used for access to Google Cloud services like
      # Cloud Storage.
      GOOGLE_CLOUD = 3
    end
  end

  # Enum State defines possible states of VMware Engine network.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The VMware Engine network is being created.
    CREATING = 1

    # The VMware Engine network is ready.
    ACTIVE = 2

    # The VMware Engine network is being updated.
    UPDATING = 3

    # The VMware Engine network is being deleted.
    DELETING = 4
  end

  # Enum Type defines possible types of VMware Engine network.
  module Type
    # The default value. This value should never be used.
    TYPE_UNSPECIFIED = 0

    # Network type used by private clouds created in projects without a network
    # of type `STANDARD`. This network type is no longer used for new VMware
    # Engine private cloud deployments.
    LEGACY = 1
  end
end