Class: Google::Cloud::VmwareEngine::V1::NetworkPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::VmwareEngine::V1::NetworkPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb
Overview
Represents a network policy resource. Network policies are regional resources. You can use a network policy to enable or disable internet access and external IP access. Network policies are associated with a VMware Engine network, which might span across regions. For a given region, a network policy applies to all private clouds in the VMware Engine network associated with the policy.
Defined Under Namespace
Classes: NetworkService
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#edge_services_cidr ⇒ ::String
Required.
-
#external_ip ⇒ ::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService
Network service that allows External IP addresses to be assigned to VMware workloads.
-
#internet_access ⇒ ::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService
Network service that allows VMware workloads to access the internet.
-
#name ⇒ ::String
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#vmware_engine_network ⇒ ::String
Optional.
-
#vmware_engine_network_canonical ⇒ ::String
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Creation time of this resource.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#description ⇒ ::String
Returns Optional. User-provided description for this network policy.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#edge_services_cidr ⇒ ::String
Returns Required. IP address range in CIDR notation used to create internet access and external IP access. An RFC 1918 CIDR block, with a "/26" prefix, is required. The range cannot overlap with any prefixes either in the consumer VPC network or in use by the private clouds attached to that VPC network.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#external_ip ⇒ ::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService
Returns Network service that allows External IP addresses to be assigned to VMware
workloads. This service can only be enabled when internet_access is also
enabled.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#internet_access ⇒ ::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService
Returns Network service that allows VMware workloads to access the internet.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#name ⇒ ::String (readonly)
Returns Output only. The resource name of this network policy.
Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/us-central1/networkPolicies/my-network-policy.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#uid ⇒ ::String (readonly)
Returns Output only. System-generated unique identifier for the resource.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last update time of this resource.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#vmware_engine_network ⇒ ::String
Returns Optional. The relative resource name of the VMware Engine network.
Specify the name in the following form:
projects/{project}/locations/{location}/vmwareEngineNetworks/{vmware_engine_network_id}
where {project} can either be a project number or a project ID.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |
#vmware_engine_network_canonical ⇒ ::String (readonly)
Returns Output only. The canonical name of the VMware Engine network in the form:
projects/{project_number}/locations/{location}/vmwareEngineNetworks/{vmware_engine_network_id}.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'proto_docs/google/cloud/vmwareengine/v1/vmwareengine_resources.rb', line 526 class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a network service that is managed by a `NetworkPolicy` resource. # A network service provides a way to control an aspect of external access to # VMware workloads. For example, whether the VMware workloads in the # private clouds governed by a network policy can access or be accessed from # the internet. # @!attribute [rw] enabled # @return [::Boolean] # True if the service is enabled; false otherwise. # @!attribute [r] state # @return [::Google::Cloud::VmwareEngine::V1::NetworkPolicy::NetworkService::State] # Output only. State of the service. New values may be added to this enum # when appropriate. class NetworkService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum State defines possible states of a network policy controlled # service. module State # Unspecified service state. This is the default value. STATE_UNSPECIFIED = 0 # Service is not provisioned. UNPROVISIONED = 1 # Service is in the process of being provisioned/deprovisioned. RECONCILING = 2 # Service is active. ACTIVE = 3 end end end |